# Package Manager

[![Build Status](https://travis-ci.com/TirsvadCLI-Tools/PackageManager.svg?branch=main)](https://travis-ci.com/TirsvadCLI-Tools/PackageManager)
[![Coverage Status](https://coveralls.io/repos/github/TirsvadCLI-Tools/PackageManager/badge.svg?branch=main)](https://coveralls.io/github/TirsvadCLI-Tools/PackageManager?branch=main)

Package Manager for different distrobution of linux.

## Conventions

\# - requires given linux commands to be executed with root privileges either directly as a root user or by use of sudo command
$ - requires given linux commands to be executed as a regular non-privileged user

### Installation

  $ pip install package-manager-TirsvadCLI

### TODO

* Package install
  * Add support for fedora and centos

### Development

Want to contribute? Great!
